@@ -16,7 +16,7 @@ our @EXPORT = qw(GetAccount);
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 # Load the required package module.
 use CryptoTron::JsonHttp;
@@ -40,15 +40,16 @@ our $METHOD = "POST";
 #                                                                              #
 # @argument $address    Base58 address      (scalar)                           #
 #           $outflag    Output format flag  (scalar)                           # 
+#           $visible    Visible switch      (scalar)                           # 
 # @return   $json_data  Response content    (scalar)                           #
 # ---------------------------------------------------------------------------- #
 sub GetAccount {
-    # Assign the argument(s) to the local variable.
+    # Assign the arguments to the local array.
     my ($args) = @_;
     # Set the local variables.
     my $address = (defined $args->{PublicAddr} ? $args->{PublicAddr} : "");
     my $outflag = (defined $args->{OutputFlag} ? $args->{OutputFlag} : "RAW");
-    my $visible = (defined $args->{Visible} ? $args->{Visible} : "True");
+    my $visible = (defined $args->{VisibleSwitch} ? $args->{VisibleSwitch} : "True");
     # Initialise the local variables. 
     my $payload = "";
     my $content = "";
@@ -85,25 +86,39 @@ CryptoTron::GetAccount - Perl extension for use with the blockchain of the crypt
 
   use CryptoTron::GetAccount;
 
-  # Initialise the public key as Base58 address.
-  my $PublicKeyBase58 = 'TQHgMpVzWkhSsRB4BzZgmV8uW4cFL8eaBr';
+  # Set the public key as Base58 address.
+  my $PublicKeyBase58 = "TY2fJ7AcsnQhfW3UJ1cjEUak5vkM87KC6R";
 
   # Set the output format flag.
   my $OutputFlag = ["RAW"|"STR"|""];
 
-  # Get response and print the result into the terminal window.
-  my $response = WithdrawBalance({
-      address => $PublicKeyBase58,
-      outflag => $OutputFlag
+  # Set the visible switch.
+  my $VisibleSwitch = ["True"|"False"|""];
+
+  # Get the account info from the blockchain.
+  my $account_info = GetAccount({
+      PublicAddr => $PublicKeyBase58
+      [, OutputFlag => $OutputFlag]
+      [, VisibleSwitch => $VisibleSwitch]
   });
-  print $response;
 
   # Print the account info into the terminal window.
   print $account_info;
 
 =head1 DESCRIPTION
 
-The module requests the withdraw balance infos from the Tron blockchain.
+The module requests the account information of an account from the Tron
+blockchain using the so-called FULL-NODE HTTP API from the Tron network.
+For HTTP requests the methods C<POST> or C<GET> used in general. For the
+method C<GetAccount> the used method is C<POST>. The switch visible can be
+set to True or False. If the switch is set to True a Base58 address is used.
+If the switch is set to False a Hex address is used. A request results in a
+response in JSON format. The module returns formated string JSON data as well
+as unformated raw JSON data. 
+
+=head1 MODULE METHOD
+
+  GetAccount()
 
 =head1 SEE ALSO
 
